@@ -71,6 +71,7 @@ class DepartmentViewSet(object):
         """
         pass
 
+    # def department_user_list(self, department_id: int, page: int = 1, size: int = 20):
     def department_user_list(self, department_id: int, page: int = 1, size: int = 20):
         """
         通过部门获取部门下的用户
@@ -79,7 +80,8 @@ class DepartmentViewSet(object):
         :param size: 每页数量
         :return:
         """
-        return get_department_user(self.organization_id, department_id, page, size)
+        # return get_department_user(self.organization_id, department_id, page, size)
+        return get_department_user(self.organization_id, department_id)
 
     def create_department_user(self, department_id: int, user_ids: list):
         """
